summaryrefslogtreecommitdiff
path: root/src/town.h
diff options
context:
space:
mode:
authorsmatz <smatz@openttd.org>2009-06-23 09:52:26 +0000
committersmatz <smatz@openttd.org>2009-06-23 09:52:26 +0000
commita50ba1b8c1afc164cf14750d9c1a89dfec9dd25a (patch)
treeb5ac362a349f29b8ddc25f933433adb792827ad6 /src/town.h
parent5ef0745254f8fe94f608ac5e1f31c8bb47f1a336 (diff)
downloadopenttd-a50ba1b8c1afc164cf14750d9c1a89dfec9dd25a.tar.xz
(svn r16632) -Codechange: rename Town::flags12 to Town::flags
Diffstat (limited to 'src/town.h')
-rw-r--r--src/town.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/town.h b/src/town.h
index d1658b2b8..0f34d1fd3 100644
--- a/src/town.h
+++ b/src/town.h
@@ -123,7 +123,7 @@ struct Town : TownPool::PoolItem<&_town_pool> {
* bit 0 = Building funds received
* bit 1 = CHURCH
* bit 2 = STADIUM */
- byte flags12;
+ byte flags;
/* level of noise that all the airports are generating */
uint16 noise_reached;
@@ -272,11 +272,11 @@ static const byte TOWN_GROWTH_FREQUENCY = 70;
* construction. */
static const byte TOWN_HOUSE_COMPLETED = 3;
/** This enum is used in conjonction with town->flags12.
* IT simply states what bit is used for.
* It is pretty unrealistic (IMHO) to only have one church/stadium
* per town, NO MATTER the population of it.
* And there are 5 more bits available on flags12...
*/
enum {
TOWN_IS_FUNDED = 0, ///< Town has received some funds for
@@ -272,11 +272,11 @@ static const byte TOWN_GROWTH_FREQUENCY = 70;
* construction. */
static const byte TOWN_HOUSE_COMPLETED = 3;
-/** This enum is used in conjonction with town->flags12.
+/** This enum is used in conjonction with town->flags.
* IT simply states what bit is used for.
* It is pretty unrealistic (IMHO) to only have one church/stadium
@@ -272,11 +272,11 @@ static const byte TOWN_GROWTH_FREQUENCY = 70;
* It is pretty unrealistic (IMHO) to only have one church/stadium
* per town, NO MATTER the population of it.
- * And there are 5 more bits available on flags12...
+ * And there are 5 more bits available on flags...
*/
enum {